/// <reference types="node" />
import * as fs from 'fs';
import { JsonMap, Nullable, Optional } from '@salesforce/ts-types';
import { AsyncOptionalCreatable } from '@salesforce/kit';
import { AuthInfoConfig } from '../../config/authInfoConfig';
import { GlobalInfo } from '../globalInfoConfig';
import { SfOrgs, SfOrg } from '../types';
import { AuthFields } from '../../org';
import { ConfigFile } from '../../config/configFile';
import { ConfigContents } from '../../config/configStore';
/**
 * @deprecated
 */
export declare class GlobalInfoOrgAccessor {
    private globalInfo;
    constructor(globalInfo: GlobalInfo);
    getAll(decrypt?: boolean): SfOrgs;
    get(username: string, decrypt?: boolean): Optional<SfOrg>;
    has(username: string): boolean;
    set(username: string, org: SfOrg): void;
    update(username: string, org: Partial<SfOrg>): void;
    unset(username: string): void;
}
export declare abstract class BaseOrgAccessor<T extends ConfigFile, P extends ConfigContents> extends AsyncOptionalCreatable {
    private configs;
    private contents;
    private logger;
    read(username: string, decrypt?: boolean, throwOnNotFound?: boolean): Promise<Nullable<P>>;
    readAll(decrypt?: boolean): Promise<P[]>;
    get(username: string, decrypt?: boolean): Nullable<P>;
    getAll(decrypt?: boolean): P[];
    has(username: string): boolean;
    exists(username: string): Promise<boolean>;
    stat(username: string): Promise<Nullable<fs.Stats>>;
    hasFile(username: string): Promise<boolean>;
    list(): Promise<string[]>;
    set(username: string, org: P): void;
    update(username: string, org: Partial<P> & JsonMap): void;
    remove(username: string): Promise<void>;
    write(username: string): Promise<Nullable<P>>;
    protected init(): Promise<void>;
    private getAllFiles;
    private parseUsername;
    private parseFilename;
    protected abstract initAuthFile(username: string, throwOnNotFound?: boolean): Promise<T>;
    protected abstract getFileRegex(): RegExp;
    protected abstract getFileExtension(): string;
}
export declare class OrgAccessor extends BaseOrgAccessor<AuthInfoConfig, AuthFields> {
    protected initAuthFile(username: string, throwOnNotFound?: boolean): Promise<AuthInfoConfig>;
    protected getFileRegex(): RegExp;
    protected getFileExtension(): string;
}
